#include <kconfig.h>

#include "gesture.h"

Q_UINT32 Gesture::_sUIDCounter = 0;

Gesture::Gesture()
  : _data(QString::null), _action(QString::null), _name("Unknown"),
    _uid(_sUIDCounter++)
  {
  }

Gesture::Gesture(const QString &data)
  : _data(data), _action(QString::null), _name("Unknown"),
    _uid(_sUIDCounter++)
  {
  }

Gesture::~Gesture()
  {
  }

bool Gesture::operator==(const Gesture &compareTo)
  {
  return (_data == compareTo.getData());
  }

void Gesture::readOptions(KConfig &config)
  {
  _data = config.readEntry("Data", QString::null);
  _action = config.readEntry("Action", QString::null);
  _name = config.readEntry("Name", QString("Unknown"));
  }

void Gesture::writeOptions(KConfig &config)
  {
  config.writeEntry("Data", _data);
  config.writeEntry("Action", _action);
  config.writeEntry("Name", _name);
  }

///////////////////////////////
// Static loading and saving methods

QList<Gesture> Gesture::readGestures(KConfig &config)
  {
  Gesture *gest = NULL;
  Q_UINT32 count = 0;
  QString groupName;
  QList<Gesture> gList;
  
  config.setGroup("Gestures");
  count = config.readNumEntry("Number");

  for (Q_UINT32 index = 0; index < count; index++)
    {
    groupName = "Gesture ";
    groupName += QString::number(index);

    config.setGroup(groupName);
    gest = new Gesture;
    gest->readOptions(config);

    gList.append(gest);
    }

  return gList;
  }

void Gesture::writeGestures(QList<Gesture> &gList, KConfig &config)
  {
  QListIterator<Gesture> iter(gList);
  Q_UINT32 index = 0;
  QString groupName;
  
  for (iter.toFirst(); iter.current(); ++iter)
    {
    groupName = "Gesture ";
    groupName += QString::number(index);

    config.setGroup(groupName);

    iter.current()->writeOptions(config);
    index++;
    }

  config.setGroup("Gestures");
  config.writeEntry("Number", gList.count());
  }
